@@ -1,4 +1,4 @@
 from tally.tally import Tally
 from tally.dataset import DataSet
 from tally.build import Build
-from tally.tally import result_to_dataframe
+from tally.helpers import result_to_dataframe
