@@ -2,20 +2,7 @@ import json
 import requests
 import pandas as pd
 import copy
-
-def result_to_dataframe(json_dict):
-    """ Deserializes a dataframe that was serialized with orient='split'
-    """
-    if 'column_names' and 'index_names' in json_dict.keys():
-        columns = pd.MultiIndex.from_tuples(json_dict['columns'], names=json_dict['column_names'])
-        index = pd.MultiIndex.from_tuples(json_dict['index'], names=json_dict['index_names'])
-    else:
-        columns = json_dict['columns']
-        index = json_dict['index']
-    df = pd.DataFrame(data=json_dict['data'])
-    df.columns = columns
-    df.index = index
-    return df
+from .decorators import verify_token
 
 class Tally:
     """Tally is a wrapper for the cloud-based Tally API.
@@ -49,7 +36,7 @@ class Tally:
 
         """
         self.host = host
-        if ssl:
+        if ssl == True or ssl == 'True':
             self.base_url = "https://{}".format(host)
         else:
             self.base_url = "http://{}".format(host)
@@ -90,6 +77,7 @@ class Tally:
         result = json.loads(result.content)
         return result
 
+    @verify_token
     def post_request(self, resource, action="", data={}, files=None):
         """Send a POST request to the API with a wrapper.
 
